(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12522,        364]*)
(*NotebookOutlinePosition[     13167,        386]*)
(*  CellTagsIndexPosition[     13123,        382]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \( (*\ For\ refraction\ case, \ 
      this\ script\ derives\ the\ local\ GLC\ chracteristic\ equation\ \
coefficients\ using\ the\ local\ refraction\ ray\ manifold, \ 
      we\ use\ a\ linear\ combination\ to\ approximate\ Snell' 
        s\ Law\ *) \)], "Input"],

Cell[BoxData[{
    \(i = {dx, dy, \(-1\)}/Sqrt[bi]; \ \  (*\ 
      i\ is\ the\ incident\ ray\ direction\ *) \n
    bi = dx*dx + dy*dy + 1;\ \  (*\ 
      bi\ is\ the\ squared\ length\ of\ incident\ direction\ *) \), "\n", 
    \(\(n = {\(-zx\), \(-zy\), 1}/Sqrt[bn];\)\  (*\ 
      n\ is\ the\ normal\ direction\ *) \), "\n", 
    \(\(bn = zx*zx + zy*zy + 1;\)\  (*\ 
      bn\ is\ the\ squared\ length\ of\ the\ normal\ direction\ *) \), "\n", 
    \(\(\(np = {zx, zy, \(-1\)}/Sqrt[bn]\)\(;\)\(\ \ \)\( (*\ 
      np\ is\ the\ direction\ opposite\ to\ n\ *) \)\(\n\)\(r = {rx, 
          ry, \(-1\)}/Sqrt[br]\)\(;\)\(\ \)\( (*\ 
      r\ is\ the\ refracted\ ray\ direction\ *) \)\(\n\)\(br = 
      rx*rx + ry*ry + 1\)\(;\)\(\ \)\( (*\ 
      br\ is\ the\ squared\ length\ of\ the\ refracted\ ray\ direction\ *) \)\
\)\)}], "Input"],

Cell[BoxData[
    \(\(\(r = \((1/m)\)*i + \((\((m - 1)\)/m)\)*np\)\(;\)\(\ \)\( (*\ 
      linear\ combination\ of\ i\ and\ m\ to\ get\ r\ *) \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(r\)\(=\)\(Simplify[r*Sqrt[bi]*Sqrt[bn]]\)\(\ \)\( (*\ 
        scaled\ version\ of\ r\ *) \)\)\)], "Input"],

Cell[BoxData[
    \({\(\@\(1 + dx\^2 + dy\^2\)\ \((\(-1\) + m)\)\ zx + dx\ \@\(1 + zx\^2 + \
zy\^2\)\)\/m, \(\@\(1 + dx\^2 + dy\^2\)\ \((\(-1\) + m)\)\ zy + dy\ \@\(1 + \
zx\^2 + zy\^2\)\)\/m, \(\@\(1 + dx\^2 + dy\^2\) - \@\(1 + dx\^2 + dy\^2\)\ m \
- \@\(1 + zx\^2 + zy\^2\)\)\/m}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(rx\)\(=\)\(Simplify[\((\(\@\(1 + dx\^2 + dy\^2\)\ \((\(-1\) + m)\)\ \
zx + dx\ \@\(1 + zx\^2 + zy\^2\)\)\/m)\)/\((\(\@\(1 + dx\^2 + dy\^2\) - \@\(1 \
+ dx\^2 + dy\^2\)\ m - \@\(1 + zx\^2 + zy\^2\)\)\/m)\)*\(-1\)]\)\(\ \)\( (*\ 
        to\ get\ the\ form\ of\ [rx, ry, \(-1\)]*) \)\)\)], "Input"],

Cell[BoxData[
    \(\(\@\(1 + dx\^2 + dy\^2\)\ \((\(-1\) + m)\)\ zx + dx\ \@\(1 + zx\^2 + \
zy\^2\)\)\/\(\(-\@\(1 + dx\^2 + dy\^2\)\) + \@\(1 + dx\^2 + dy\^2\)\ m + \
\@\(1 + zx\^2 + zy\^2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(ry\)\(=\)\(Simplify[\((\(\@\(1 + dx\^2 + dy\^2\)\ \((\(-1\) + m)\)\ \
zy + dy\ \@\(1 + zx\^2 + zy\^2\)\)\/m)\)/\((\(\@\(1 + dx\^2 + dy\^2\) - \@\(1 \
+ dx\^2 + dy\^2\)\ m - \@\(1 + zx\^2 + zy\^2\)\)\/m)\)*\(-1\)]\)\( (*\ 
        to\ get\ the\ form\ of\ [rx, ry, \(-1\)]*) \)\)\)], "Input"],

Cell[BoxData[
    \(\(\@\(1 + dx\^2 + dy\^2\)\ \((\(-1\) + m)\)\ zy + dy\ \@\(1 + zx\^2 + \
zy\^2\)\)\/\(\(-\@\(1 + dx\^2 + dy\^2\)\) + \@\(1 + dx\^2 + dy\^2\)\ m + \
\@\(1 + zx\^2 + zy\^2\)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\( (*\ calculate\ the\ sigma, \ tau, \ u, \ 
      v\ values*) \)\(\[IndentingNewLine]\)\(\(s = rx;\)\n
    \(t = ry;\)\n
    \(u = x - z*s;\)\n
    \(v = y - z*t;\)\)\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*\ set\ zx, \ zy, \ 
      and\ z\ as\ a\ function\ of\ x\ and\ y\ in\ order\ to\ calculate\ \
partial\ dirivatives\ w . r . t . \ 
          x\ and\ y\ *) \)\(\[IndentingNewLine]\)\(\(zx = 
        fzx[x, y];\)\[IndentingNewLine]
    \(zy = fzy[x, y];\)\[IndentingNewLine]
    \(z = fz[x, y];\)\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(s\)], "Input"],

Cell[BoxData[
    \(\(\@\(1 + dx\^2 + dy\^2\)\ \((\(-1\) + m)\)\ zx + dx\ \@\(1 + zx\^2 + \
zy\^2\)\)\/\(\(-\@\(1 + dx\^2 + dy\^2\)\) + \@\(1 + dx\^2 + dy\^2\)\ m + \
\@\(1 + zx\^2 + zy\^2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(t\)], "Input"],

Cell[BoxData[
    \(\(\@\(1 + dx\^2 + dy\^2\)\ \((\(-1\) + m)\)\ zy + dy\ \@\(1 + zx\^2 + \
zy\^2\)\)\/\(\(-\@\(1 + dx\^2 + dy\^2\)\) + \@\(1 + dx\^2 + dy\^2\)\ m + \
\@\(1 + zx\^2 + zy\^2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(u\)], "Input"],

Cell[BoxData[
    \(x - \(z\ \((\@\(1 + dx\^2 + dy\^2\)\ \((\(-1\) + m)\)\ zx + dx\ \@\(1 + \
zx\^2 + zy\^2\))\)\)\/\(\(-\@\(1 + dx\^2 + dy\^2\)\) + \@\(1 + dx\^2 + \
dy\^2\)\ m + \@\(1 + zx\^2 + zy\^2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(v\)], "Input"],

Cell[BoxData[
    \(y - \(z\ \((\@\(1 + dx\^2 + dy\^2\)\ \((\(-1\) + m)\)\ zy + dy\ \@\(1 + \
zx\^2 + zy\^2\))\)\)\/\(\(-\@\(1 + dx\^2 + dy\^2\)\) + \@\(1 + dx\^2 + \
dy\^2\)\ m + \@\(1 + zx\^2 + zy\^2\)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\( (*\ 
      calculate\ the\ first\ order\ partial\ derivatives\ of\ sigma, \ tau, \ 
      u, \ and\ v\ w . r . t . \ 
          x\ and\ y\ *) \)\(\[IndentingNewLine]\)\(\(sx = 
        D[s, x];\)\[IndentingNewLine]
    \(sy = D[s, y];\)\[IndentingNewLine]
    \(tx = D[t, x];\)\[IndentingNewLine]
    \(ty = D[t, y];\)\[IndentingNewLine]
    \(ux = D[u, x];\)\[IndentingNewLine]
    \(uy = D[u, y];\)\[IndentingNewLine]
    \(vx = D[v, x];\)\[IndentingNewLine]
    \(vy = D[v, y];\)\)\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*\ 
      calculate\ the\ GLC\ chracteristic\ equation\ coefficients\ using\ \
first\ order\ derivatives\ of\ sigma, \ tau, \ u, \ 
      and\ v\ w . r . t . \ x\ and\ y\ *) \)\(\[IndentingNewLine]\)\(\(A = 
        sx*ty - sy*tx;\)\[IndentingNewLine]
    \(B = sx*vy - sy*vx - tx*uy + ty*ux;\)\[IndentingNewLine]
    \(CC = ux*vy - uy*vx;\)\)\)\)], "Input"],

Cell[BoxData[
    RowBox[{\( (*\ 
        set\ the\ partial\ derivatives\ to\ a\ simplified\ notion, \ 
        where\ wx, \ wy\ are\ equivalent\ to\ zx, \ zy; \ wxx, \ wxy, \ 
        wyy\ are\ equivalent\ to\ zxx, \ zxy, \ zyy\ *) \), 
      "\[IndentingNewLine]", 
      RowBox[{\(fzx[x, y] = wx;\), "\[IndentingNewLine]", \(fzy[x, y] = wy;\),
         "\[IndentingNewLine]", \(fz[x, y] = w;\), "\[IndentingNewLine]", " ",
         
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["fzy", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(x, y\), "]"}], "=", "wyy"}], 
          ";"}], "\[IndentingNewLine]", " ", 
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["fzy", 
                TagBox[\((1, 0)\),
                  Derivative],
                MultilineFunction->None], "[", \(x, y\), "]"}], "=", "wxy"}], 
          ";"}], "\[IndentingNewLine]", " ", 
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["fzx", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(x, y\), "]"}], "=", "wxy"}], 
          ";"}], "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["fzx", 
                TagBox[\((1, 0)\),
                  Derivative],
                MultilineFunction->None], "[", \(x, y\), "]"}], "=", "wxx"}], 
          ";"}], "\[IndentingNewLine]", " ", 
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["fz", 
                TagBox[\((1, 0)\),
                  Derivative],
                MultilineFunction->None], "[", \(x, y\), "]"}], "=", "wx"}], 
          ";"}], "\[IndentingNewLine]", " ", 
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["fz", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(x, y\), "]"}], "=", "wy"}], 
          ";"}]}]}]], "Input"],

Cell[BoxData[{
    \(\(Clear[dx];\)\), "\[IndentingNewLine]", 
    \(\(Clear[dy];\)\)}], "Input"],

Cell[BoxData[
    \(\(\( (*\ Set\ the\ simplification\ equation, \ 
      since\ we\ choose\ the\ local\ normal\ direction\ as\ the\ z - 
        axis\ of\ our\ 2  
          PP\ parametrization\ *) \)\(\ \)\(\[IndentingNewLine]\)\(\(wx = 
        0;\)\[IndentingNewLine]
    \(wy = 0;\)\[IndentingNewLine]
    \(w = 0;\)\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[A]\)], "Input"],

Cell[BoxData[
    \(\(-\(\(\((1 + dx\^2 + dy\^2)\)\ \((\(-1\) + m)\)\^2\ \((wxy\^2 - 
                wxx\ wyy)\)\)\/\((1 - \@\(1 + dx\^2 + dy\^2\) + \@\(1 + dx\^2 \
+ dy\^2\)\ m)\)\^2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[B]\)], "Input"],

Cell[BoxData[
    \(\(\@\(1 + dx\^2 + dy\^2\)\ \((\(-1\) + m)\)\ \((wxx + wyy)\)\)\/\(1 - \
\@\(1 + dx\^2 + dy\^2\) + \@\(1 + dx\^2 + dy\^2\)\ m\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CC\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(wx = 0;\)\), "\[IndentingNewLine]", 
    \(\(wy = 0;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[B]\)], "Input"],

Cell[BoxData[
    \(\((\((\(-1\) + 
              m)\)\ \((2\ \((1 + dx\^2 + dy\^2)\)\ \((\(-1\) + 
                    m)\)\ w\ wxy\^2 + \((\(-1\) + \@\(1 + dx\^2 + dy\^2\) + 
                    dx\^2\ \((\(-1\) + m)\) + dy\^2\ \((\(-1\) + m)\) + 
                    m)\)\ wyy + 
              wxx\ \((\(-1\) + \@\(1 + dx\^2 + dy\^2\) + m + 2\ w\ wyy - 
                    2\ m\ w\ wyy - 
                    dx\^2\ \((\(-1\) + m)\)\ \((\(-1\) + 2\ w\ wyy)\) - 
                    dy\^2\ \((\(-1\) + m)\)\ \((\(-1\) + 
                          2\ w\ wyy)\))\))\))\)/\((1 - \@\(1 + dx\^2 + \
dy\^2\) + \@\(1 + dx\^2 + dy\^2\)\ m)\)\^2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[CC]\)], "Input"],

Cell[BoxData[
    \(\(-\(\(\((1 + dx\^2 + 
                  dy\^2)\)\ \((\(-1\) + m)\)\^2\ w\^2\ wxy\^2\)\/\((1 - \@\(1 \
+ dx\^2 + dy\^2\) + \@\(1 + dx\^2 + dy\^2\)\ m)\)\^2\)\) + \((1 - \(\@\(1 + \
dx\^2 + dy\^2\)\ \((\(-1\) + m)\)\ w\ wxx\)\/\(1 - \@\(1 + dx\^2 + dy\^2\) + \
\@\(1 + dx\^2 + dy\^2\)\ m\))\)\ \((1 - \(\@\(1 + dx\^2 + dy\^2\)\ \((\(-1\) \
+ m)\)\ w\ wyy\)\/\(1 - \@\(1 + dx\^2 + dy\^2\) + \@\(1 + dx\^2 + dy\^2\)\ \
m\))\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(B = \(-\(\(\((\(-1\) + m)\)\ \((\(-1\) + \@\(1 + dx\^2 + dy\^2\) + 
                    dx\^2\ \((\(-1\) + m)\) + dy\^2\ \((\(-1\) + m)\) + 
                    m)\)\ \((wxx + 
                    wxy)\)\)\/\((1 - \@\(1 + dx\^2 + dy\^2\) + \@\(1 + dx\^2 \
+ dy\^2\)\ m)\)\^2\)\);\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*\ 
      further\ alter\ the\ viewing\ direction\ s . t . \ dx = \(0\ and\ dy = 
          0\)\ *) \)\(\[IndentingNewLine]\)\(\(dx = 0;\)\[IndentingNewLine]
    \(dy = 0;\)\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[B]\)], "Input"],

Cell[BoxData[
    \(\(-\(\(\((\(-1\) + m)\)\ \((wxx + wxy)\)\)\/m\)\)\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowSize->{647, 907},
WindowMargins->{{Automatic, -4}, {Automatic, -3}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 283, 5, 90, "Input"],
Cell[2040, 58, 834, 15, 190, "Input"],
Cell[2877, 75, 159, 2, 50, "Input"],

Cell[CellGroupData[{
Cell[3061, 81, 131, 2, 30, "Input"],
Cell[3195, 85, 295, 4, 127, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3527, 94, 320, 4, 169, "Input"],
Cell[3850, 100, 206, 3, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4093, 108, 314, 4, 169, "Input"],
Cell[4410, 114, 206, 3, 52, "Output"]
}, Open  ]],
Cell[4631, 120, 204, 5, 110, "Input"],
Cell[4838, 127, 338, 7, 110, "Input"],

Cell[CellGroupData[{
Cell[5201, 138, 34, 1, 30, "Input"],
Cell[5238, 141, 206, 3, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5481, 149, 34, 1, 30, "Input"],
Cell[5518, 152, 206, 3, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5761, 160, 34, 1, 30, "Input"],
Cell[5798, 163, 219, 3, 54, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6054, 171, 34, 1, 30, "Input"],
Cell[6091, 174, 219, 3, 54, "Output"]
}, Open  ]],
Cell[6325, 180, 524, 12, 210, "Input"],
Cell[6852, 194, 384, 7, 110, "Input"],
Cell[7239, 203, 2121, 56, 250, "Input"],
Cell[9363, 261, 97, 2, 50, "Input"],
Cell[9463, 265, 338, 7, 130, "Input"],

Cell[CellGroupData[{
Cell[9826, 276, 44, 1, 30, "Input"],
Cell[9873, 279, 202, 3, 54, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10112, 287, 44, 1, 30, "Input"],
Cell[10159, 290, 160, 2, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10356, 297, 35, 1, 30, "Input"],
Cell[10394, 300, 35, 1, 29, "Output"]
}, Open  ]],
Cell[10444, 304, 91, 2, 50, "Input"],

Cell[CellGroupData[{
Cell[10560, 310, 44, 1, 30, "Input"],
Cell[10607, 313, 653, 11, 145, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11297, 329, 45, 1, 30, "Input"],
Cell[11345, 332, 456, 7, 101, "Output"]
}, Open  ]],
Cell[11816, 342, 316, 5, 68, "Input"],
Cell[12135, 349, 216, 4, 70, "Input"],

Cell[CellGroupData[{
Cell[12376, 357, 44, 1, 30, "Input"],
Cell[12423, 360, 83, 1, 42, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

