(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     25412,        542]*)
(*NotebookOutlinePosition[     26055,        564]*)
(*  CellTagsIndexPosition[     26011,        560]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \( (*\ For\ refraction\ case, \ 
      this\ script\ derives\ the\ local\ GLC\ chracteristic\ equation\ \
coefficients\ using\ the\ local\ refraction\ ray\ manifold, \ 
      we\ do\ not\ use\ any\ approximation\ for\ Snell' 
        s\ Law\ *) \)], "Input"],

Cell[BoxData[
    \(\(\( (*\ i, \ 
      n\ are\ unit\ vector\ of\ incident\ ray\ direction\ and\ normal\ \
direction\ *) \)\(\[IndentingNewLine]\)\(\(bi = dx*dx + dy*dy + 1;\)\n
    \(i = {dx, dy, \(-1\)}/Sqrt[bi];\)\n
    \(bn = zx*zx + zy*zy + 1;\)\n
    \(n = {\(-zx\), \(-zy\), 1}/Sqrt[bn];\)\n
    \(np = {zx, zy, \(-1\)}/Sqrt[bn];\)\n
    \(br = rx*rx + ry*ry + 1;\)\n
    \(r = {rx, ry, 1}/Sqrt[br];\)\[IndentingNewLine] (*\ 
      cosf1\ and\ cosf2\ are\ cosine\ falues\ of\ incident\ angle\ phi_  
        1\ and\ exitence\ angle\ phi_  2*) \n
    \(cosf1 = \(-1\)*\((i . n)\);\)\n
    \(cosf2 = \(-1\)*\((r . n)\);\)\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      solve\ the\ following\ equation\ array\ to\ get\ the\ refracted\ ray\ \
direction\ *) \)\(\[IndentingNewLine]\)\(Solve[{1 - cosf1*cosf1 == 
          m*m*\((1 - cosf2*cosf2)\), 
        ry\ zx + dy\ \((rx + zx)\) - rx\ zy - dx\ \((ry + zy)\) \[Equal] 
          0}, {rx, ry}]\)\)\)], "Input"],

Cell[BoxData[
    \({{rx \[Rule] \(\(1\/\(\(-dy\) + zy\)\)\((dy\ zx - 
              dx\ zy + \(dx\^2\ dy\ zx\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\
\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\^2\) - \(2\ dx\ dy\ \
zx\^2\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx \
- zx\^2 + 2\ dy\ zy - zy\^2\) + \(dy\ zx\^3\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + \
dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\^2\) - \(dx\^3\
\ zy\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - \
zx\^2 + 2\ dy\ zy - zy\^2\) + \(dx\ m\^2\ zy\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + \
dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\^2\) + \(dx\^3\
\ m\^2\ zy\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\
\ zx - zx\^2 + 2\ dy\ zy - zy\^2\) + \(dx\ dy\^2\ m\^2\ zy\)\/\(\(-dx\^2\) - \
dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\
\^2\) + \(2\ dx\^2\ zx\ zy\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + \
dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\^2\) - \(m\^2\ zx\ \
zy\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - \
zx\^2 + 2\ dy\ zy - zy\^2\) - \(dx\^2\ m\^2\ zx\ zy\)\/\(\(-dx\^2\) - dy\^2 + \
m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\^2\) - \
\(dy\^2\ m\^2\ zx\ zy\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\
\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\^2\) - \(dx\ zx\^2\ zy\)\/\(\(-dx\^2\
\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy \
- zy\^2\) + \((dx\ \[Sqrt]\((\((2\ dx\ dy\ zx - 2\ dy\ zx\^2 - 2\ dx\^2\ zy + \
2\ m\^2\ zy + 2\ dx\^2\ m\^2\ zy + 2\ dy\^2\ m\^2\ zy + 2\ dx\ zx\ zy)\)\^2 - 
                          4\ \((\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + 
                                dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - 
                                zy\^2)\)\ \((\(-dy\^2\) - dy\^2\ zx\^2 + 
                                2\ dy\ zy + 2\ dx\ dy\ zx\ zy - zy\^2 - 
                                dx\^2\ zy\^2 + m\^2\ zy\^2 + 
                                dx\^2\ m\^2\ zy\^2 + 
                                
                                dy\^2\ m\^2\ zy\^2)\))\))\)/\((2\ \((\(-dx\^2\
\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 
                        2\ dy\ zy - 
                        zy\^2)\))\) - \((zx\ \[Sqrt]\((\((2\ dx\ dy\ zx - 2\ \
dy\ zx\^2 - 2\ dx\^2\ zy + 2\ m\^2\ zy + 2\ dx\^2\ m\^2\ zy + 2\ dy\^2\ m\^2\ \
zy + 2\ dx\ zx\ zy)\)\^2 - 
                          4\ \((\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + 
                                dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - 
                                zy\^2)\)\ \((\(-dy\^2\) - dy\^2\ zx\^2 + 
                                2\ dy\ zy + 2\ dx\ dy\ zx\ zy - zy\^2 - 
                                dx\^2\ zy\^2 + m\^2\ zy\^2 + 
                                dx\^2\ m\^2\ zy\^2 + 
                                dy\^2\ m\^2\ zy\^2)\))\))\)/\((2\ \((\(-dx\^2\
\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 
                        2\ dy\ zy - zy\^2)\))\))\)\), 
        ry \[Rule] \((\(-2\)\ dx\ dy\ zx + 2\ dy\ zx\^2 + 2\ dx\^2\ zy - 
                2\ m\^2\ zy - 2\ dx\^2\ m\^2\ zy - 2\ dy\^2\ m\^2\ zy - 
                2\ dx\ zx\ zy - \[Sqrt]\((\((2\ dx\ dy\ zx - 2\ dy\ zx\^2 - 2\
\ dx\^2\ zy + 2\ m\^2\ zy + 2\ dx\^2\ m\^2\ zy + 2\ dy\^2\ m\^2\ zy + 2\ dx\ \
zx\ zy)\)\^2 - 4\ \((\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 
                            2\ dx\ zx - zx\^2 + 2\ dy\ zy - 
                            zy\^2)\)\ \((\(-dy\^2\) - dy\^2\ zx\^2 + 
                            2\ dy\ zy + 2\ dx\ dy\ zx\ zy - zy\^2 - 
                            dx\^2\ zy\^2 + m\^2\ zy\^2 + dx\^2\ m\^2\ zy\^2 + 
                            dy\^2\ m\^2\ zy\^2)\))\))\)/\((2\ \((\(-dx\^2\) - 
                    dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - 
                    zx\^2 + 2\ dy\ zy - 
                    zy\^2)\))\)}, {rx \[Rule] \(\(1\/\(\(-dy\) + 
                zy\)\)\((dy\ zx - 
              dx\ zy + \(dx\^2\ dy\ zx\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\
\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\^2\) - \(2\ dx\ dy\ \
zx\^2\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx \
- zx\^2 + 2\ dy\ zy - zy\^2\) + \(dy\ zx\^3\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + \
dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\^2\) - \(dx\^3\
\ zy\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - \
zx\^2 + 2\ dy\ zy - zy\^2\) + \(dx\ m\^2\ zy\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + \
dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\^2\) + \(dx\^3\
\ m\^2\ zy\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\
\ zx - zx\^2 + 2\ dy\ zy - zy\^2\) + \(dx\ dy\^2\ m\^2\ zy\)\/\(\(-dx\^2\) - \
dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\
\^2\) + \(2\ dx\^2\ zx\ zy\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + \
dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\^2\) - \(m\^2\ zx\ \
zy\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - \
zx\^2 + 2\ dy\ zy - zy\^2\) - \(dx\^2\ m\^2\ zx\ zy\)\/\(\(-dx\^2\) - dy\^2 + \
m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\^2\) - \
\(dy\^2\ m\^2\ zx\ zy\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\
\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\^2\) - \(dx\ zx\^2\ zy\)\/\(\(-dx\^2\
\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy \
- zy\^2\) - \((dx\ \[Sqrt]\((\((2\ dx\ dy\ zx - 2\ dy\ zx\^2 - 2\ dx\^2\ zy + \
2\ m\^2\ zy + 2\ dx\^2\ m\^2\ zy + 2\ dy\^2\ m\^2\ zy + 2\ dx\ zx\ zy)\)\^2 - 
                          4\ \((\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + 
                                dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - 
                                zy\^2)\)\ \((\(-dy\^2\) - dy\^2\ zx\^2 + 
                                2\ dy\ zy + 2\ dx\ dy\ zx\ zy - zy\^2 - 
                                dx\^2\ zy\^2 + m\^2\ zy\^2 + 
                                dx\^2\ m\^2\ zy\^2 + 
                                dy\^2\ m\^2\ zy\^2)\))\))\)/\((2\ \((\(-dx\^2\
\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 
                        2\ dy\ zy - 
                        zy\^2)\))\) + \((zx\ \[Sqrt]\((\((2\ dx\ dy\ zx - 2\ \
dy\ zx\^2 - 2\ dx\^2\ zy + 2\ m\^2\ zy + 2\ dx\^2\ m\^2\ zy + 2\ dy\^2\ m\^2\ \
zy + 2\ dx\ zx\ zy)\)\^2 - 
                          4\ \((\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + 
                                dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - 
                                zy\^2)\)\ \((\(-dy\^2\) - dy\^2\ zx\^2 + 
                                2\ dy\ zy + 2\ dx\ dy\ zx\ zy - zy\^2 - 
                                dx\^2\ zy\^2 + m\^2\ zy\^2 + 
                                dx\^2\ m\^2\ zy\^2 + 
                                dy\^2\ m\^2\ zy\^2)\))\))\)/\((2\ \((\(-dx\^2\
\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy 
                        - zy\^2)\))\))\)\), 
        ry \[Rule] \((\(-2\)\ dx\ dy\ zx + 2\ dy\ zx\^2 + 2\ dx\^2\ zy - 
                2\ m\^2\ zy - 2\ dx\^2\ m\^2\ zy - 2\ dy\^2\ m\^2\ zy - 
                2\ dx\ zx\ zy + \[Sqrt]\((\((2\ dx\ dy\ zx - 2\ dy\ zx\^2 - 2\
\ dx\^2\ zy + 2\ m\^2\ zy + 2\ dx\^2\ m\^2\ zy + 2\ dy\^2\ m\^2\ zy + 2\ dx\ \
zx\ zy)\)\^2 - 4\ \((\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 
                            2\ dx\ zx - zx\^2 + 2\ dy\ zy - 
                            zy\^2)\)\ \((\(-dy\^2\) - dy\^2\ zx\^2 + 
                            2\ dy\ zy + 2\ dx\ dy\ zx\ zy - zy\^2 - 
                            dx\^2\ zy\^2 + m\^2\ zy\^2 + dx\^2\ m\^2\ zy\^2 + 
                            dy\^2\ m\^2\ zy\^2)\))\))\)/\((2\ \((\(-dx\^2\) - 
                    dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - 
                    zx\^2 + 2\ dy\ zy - zy\^2)\))\)}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\( (*\ assign\ the\ result\ to\ rx, \ 
      ry\ *) \)\(\[IndentingNewLine]\)\(rx = \(1\/\(\(-dy\) + 
                zy\)\) \((dy\ zx - 
              dx\ zy + \(dx\^2\ dy\ zx\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\
\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\^2\) - \(2\ dx\ dy\ \
zx\^2\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx \
- zx\^2 + 2\ dy\ zy - zy\^2\) + \(dy\ zx\^3\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + \
dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\^2\) - \(dx\^3\
\ zy\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - \
zx\^2 + 2\ dy\ zy - zy\^2\) + \(dx\ m\^2\ zy\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + \
dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\^2\) + \(dx\^3\
\ m\^2\ zy\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\
\ zx - zx\^2 + 2\ dy\ zy - zy\^2\) + \(dx\ dy\^2\ m\^2\ zy\)\/\(\(-dx\^2\) - \
dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\
\^2\) + \(2\ dx\^2\ zx\ zy\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + \
dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\^2\) - \(m\^2\ zx\ \
zy\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - \
zx\^2 + 2\ dy\ zy - zy\^2\) - \(dx\^2\ m\^2\ zx\ zy\)\/\(\(-dx\^2\) - dy\^2 + \
m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\^2\) - \
\(dy\^2\ m\^2\ zx\ zy\)\/\(\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\
\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\^2\) - \(dx\ zx\^2\ zy\)\/\(\(-dx\^2\
\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy \
- zy\^2\) + \((dx\ \[Sqrt]\((\((2\ dx\ dy\ zx - 2\ dy\ zx\^2 - 2\ dx\^2\ zy + \
2\ m\^2\ zy + 2\ dx\^2\ m\^2\ zy + 2\ dy\^2\ m\^2\ zy + 2\ dx\ zx\ zy)\)\^2 - 
                          4\ \((\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + 
                                dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - 
                                zy\^2)\)\ \((\(-dy\^2\) - dy\^2\ zx\^2 + 
                                2\ dy\ zy + 2\ dx\ dy\ zx\ zy - zy\^2 - 
                                dx\^2\ zy\^2 + m\^2\ zy\^2 + 
                                dx\^2\ m\^2\ zy\^2 + 
                                dy\^2\ m\^2\ zy\^2)\))\))\)/\((2\ \((\(-dx\^2\
\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 
                        2\ dy\ zy - 
                        zy\^2)\))\) - \((zx\ \[Sqrt]\((\((2\ dx\ dy\ zx - 2\ \
dy\ zx\^2 - 2\ dx\^2\ zy + 2\ m\^2\ zy + 2\ dx\^2\ m\^2\ zy + 2\ dy\^2\ m\^2\ \
zy + 2\ dx\ zx\ zy)\)\^2 - 
                          4\ \((\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + 
                                dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 2\ dy\ zy - 
                                zy\^2)\)\ \((\(-dy\^2\) - dy\^2\ zx\^2 + 
                                2\ dy\ zy + 2\ dx\ dy\ zx\ zy - zy\^2 - 
                                dx\^2\ zy\^2 + m\^2\ zy\^2 + 
                                dx\^2\ m\^2\ zy\^2 + 
                                dy\^2\ m\^2\ zy\^2)\))\))\)/\((2\ \((\(-dx\^2\
\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - zx\^2 + 
                        2\ dy\ zy - zy\^2)\))\))\);\)\)\)], "Input"],

Cell[BoxData[
    \(\(ry = \((\(-2\)\ dx\ dy\ zx + 2\ dy\ zx\^2 + 2\ dx\^2\ zy - 
              2\ m\^2\ zy - 2\ dx\^2\ m\^2\ zy - 2\ dy\^2\ m\^2\ zy - 
              2\ dx\ zx\ zy - \[Sqrt]\((\((2\ dx\ dy\ zx - 2\ dy\ zx\^2 - 2\ \
dx\^2\ zy + 2\ m\^2\ zy + 2\ dx\^2\ m\^2\ zy + 2\ dy\^2\ m\^2\ zy + 2\ dx\ zx\
\ zy)\)\^2 - 4\ \((\(-dx\^2\) - dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 
                          2\ dx\ zx - zx\^2 + 2\ dy\ zy - 
                          zy\^2)\)\ \((\(-dy\^2\) - dy\^2\ zx\^2 + 
                          2\ dy\ zy + 2\ dx\ dy\ zx\ zy - zy\^2 - 
                          dx\^2\ zy\^2 + m\^2\ zy\^2 + dx\^2\ m\^2\ zy\^2 + 
                          dy\^2\ m\^2\ zy\^2)\))\))\)/\((2\ \((\(-dx\^2\) - 
                  dy\^2 + m\^2 + dx\^2\ m\^2 + dy\^2\ m\^2 + 2\ dx\ zx - 
                  zx\^2 + 2\ dy\ zy - zy\^2)\))\);\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[rx]\)], "Input"],

Cell[BoxData[
    \(\((dy\^3\ zx - dy\ m\^2\ zx - dx\^2\ dy\ m\^2\ zx - dy\^3\ m\^2\ zx - 
          dx\ dy\^2\ zy - 2\ dy\^2\ zx\ zy + m\^2\ zx\ zy + 
          dx\^2\ m\^2\ zx\ zy + dy\^2\ m\^2\ zx\ zy + 2\ dx\ dy\ zy\^2 + 
          dy\ zx\ zy\^2 - dx\ zy\^3 - 
          dx\ \@\(\((dy - zy)\)\^2\ \((m\^2 - zx\^2 + m\^2\ zx\^2 + 2\ dy\ zy \
- zy\^2 + m\^2\ zy\^2 + 2\ dx\ \((zx + dy\ zx\ zy)\) + dy\^2\ \((\(-1\) - \
zx\^2 + m\^2\ \((1 + zx\^2 + zy\^2)\))\) + dx\^2\ \((\(-1\) - zy\^2 + m\^2\ \
\((1 + zx\^2 + zy\^2)\))\))\)\) + 
          zx\ \@\(\((dy - zy)\)\^2\ \((m\^2 - zx\^2 + m\^2\ zx\^2 + 2\ dy\ zy \
- zy\^2 + m\^2\ zy\^2 + 2\ dx\ \((zx + dy\ zx\ zy)\) + dy\^2\ \((\(-1\) - \
zx\^2 + m\^2\ \((1 + zx\^2 + zy\^2)\))\) + dx\^2\ \((\(-1\) - zy\^2 + m\^2\ \
\((1 + zx\^2 + zy\^2)\))\))\)\))\)/\((\((dy - zy)\)\ \((m\^2 + 
              dx\^2\ \((\(-1\) + m\^2)\) + dy\^2\ \((\(-1\) + m\^2)\) + 
              2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\^2)\))\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[ry]\)], "Input"],

Cell[BoxData[
    \(\(-\(\((dx\ dy\ zx - dy\ zx\^2 - dx\^2\ zy + m\^2\ zy + 
            dx\^2\ m\^2\ zy + dy\^2\ m\^2\ zy + 
            dx\ zx\ zy + \@\(\((dy - zy)\)\^2\ \((m\^2 - zx\^2 + m\^2\ zx\^2 \
+ 2\ dy\ zy - zy\^2 + m\^2\ zy\^2 + 2\ dx\ \((zx + dy\ zx\ zy)\) + dy\^2\ \((\
\(-1\) - zx\^2 + m\^2\ \((1 + zx\^2 + zy\^2)\))\) + dx\^2\ \((\(-1\) - zy\^2 \
+ m\^2\ \((1 + zx\^2 + zy\^2)\))\))\)\))\)/\((m\^2 + 
            dx\^2\ \((\(-1\) + m\^2)\) + dy\^2\ \((\(-1\) + m\^2)\) + 
            2\ dx\ zx - zx\^2 + 2\ dy\ zy - zy\^2)\)\)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\( (*\ calculate\ the\ sigma, \ tau, \ u, \ 
      v\ values*) \)\(\[IndentingNewLine]\)\(\(s = rx;\)\n
    \(t = ry;\)\n
    \(u = x - z*s;\)\n
    \(v = y - z*t;\)\)\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*\ set\ zx, \ zy, \ 
      and\ z\ as\ a\ function\ of\ x\ and\ y\ in\ order\ to\ calculate\ \
partial\ dirivatives\ w . r . t . \ 
          x\ and\ y\ *) \)\(\[IndentingNewLine]\)\(\(zx = 
        fzx[x, y];\)\[IndentingNewLine]
    \(zy = fzy[x, y];\)\[IndentingNewLine]
    \(z = fz[x, y];\)\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(s\)], "Input"],

Cell[BoxData[
    \(\(\@\(1 + dx\^2 + dy\^2\)\ \((\(-1\) + m)\)\ zx + dx\ \@\(1 + zx\^2 + \
zy\^2\)\)\/\(\(-\@\(1 + dx\^2 + dy\^2\)\) + \@\(1 + dx\^2 + dy\^2\)\ m + \
\@\(1 + zx\^2 + zy\^2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(t\)], "Input"],

Cell[BoxData[
    \(\(\@\(1 + dx\^2 + dy\^2\)\ \((\(-1\) + m)\)\ zy + dy\ \@\(1 + zx\^2 + \
zy\^2\)\)\/\(\(-\@\(1 + dx\^2 + dy\^2\)\) + \@\(1 + dx\^2 + dy\^2\)\ m + \
\@\(1 + zx\^2 + zy\^2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(u\)], "Input"],

Cell[BoxData[
    \(x - \(z\ \((\@\(1 + dx\^2 + dy\^2\)\ \((\(-1\) + m)\)\ zx + dx\ \@\(1 + \
zx\^2 + zy\^2\))\)\)\/\(\(-\@\(1 + dx\^2 + dy\^2\)\) + \@\(1 + dx\^2 + \
dy\^2\)\ m + \@\(1 + zx\^2 + zy\^2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(v\)], "Input"],

Cell[BoxData[
    \(y - \(z\ \((\@\(1 + dx\^2 + dy\^2\)\ \((\(-1\) + m)\)\ zy + dy\ \@\(1 + \
zx\^2 + zy\^2\))\)\)\/\(\(-\@\(1 + dx\^2 + dy\^2\)\) + \@\(1 + dx\^2 + \
dy\^2\)\ m + \@\(1 + zx\^2 + zy\^2\)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\( (*\ 
      calculate\ the\ first\ order\ partial\ derivatives\ of\ sigma, \ tau, \ 
      u, \ and\ v\ w . r . t . \ 
          x\ and\ y\ *) \)\(\[IndentingNewLine]\)\(\(sx = 
        D[s, x];\)\[IndentingNewLine]
    \(sy = D[s, y];\)\[IndentingNewLine]
    \(tx = D[t, x];\)\[IndentingNewLine]
    \(ty = D[t, y];\)\[IndentingNewLine]
    \(ux = D[u, x];\)\[IndentingNewLine]
    \(uy = D[u, y];\)\[IndentingNewLine]
    \(vx = D[v, x];\)\[IndentingNewLine]
    \(vy = D[v, y];\)\)\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*\ 
      calculate\ the\ GLC\ chracteristic\ equation\ coefficients\ using\ \
first\ order\ derivatives\ of\ sigma, \ tau, \ u, \ 
      and\ v\ w . r . t . \ x\ and\ y\ *) \)\(\[IndentingNewLine]\)\(\(A = 
        sx*ty - sy*tx;\)\[IndentingNewLine]
    \(B = sx*vy - sy*vx - tx*uy + ty*ux;\)\[IndentingNewLine]
    \(CC = ux*vy - uy*vx;\)\)\)\)], "Input"],

Cell[BoxData[
    RowBox[{\( (*\ 
        set\ the\ partial\ derivatives\ to\ a\ simplified\ notion, \ 
        where\ wx, \ wy\ are\ equivalent\ to\ zx, \ zy; \ wxx, \ wxy, \ 
        wyy\ are\ equivalent\ to\ zxx, \ zxy, \ zyy\ *) \), 
      "\[IndentingNewLine]", 
      RowBox[{\(fzx[x, y] = wx;\), "\[IndentingNewLine]", \(fzy[x, y] = wy;\),
         "\[IndentingNewLine]", \(fz[x, y] = w;\), "\[IndentingNewLine]", " ",
         
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["fzy", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(x, y\), "]"}], "=", "wyy"}], 
          ";"}], "\[IndentingNewLine]", " ", 
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["fzy", 
                TagBox[\((1, 0)\),
                  Derivative],
                MultilineFunction->None], "[", \(x, y\), "]"}], "=", "wxy"}], 
          ";"}], "\[IndentingNewLine]", " ", 
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["fzx", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(x, y\), "]"}], "=", "wxy"}], 
          ";"}], "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["fzx", 
                TagBox[\((1, 0)\),
                  Derivative],
                MultilineFunction->None], "[", \(x, y\), "]"}], "=", "wxx"}], 
          ";"}], "\[IndentingNewLine]", " ", 
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["fz", 
                TagBox[\((1, 0)\),
                  Derivative],
                MultilineFunction->None], "[", \(x, y\), "]"}], "=", "wx"}], 
          ";"}], "\[IndentingNewLine]", " ", 
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["fz", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(x, y\), "]"}], "=", "wy"}], 
          ";"}]}]}]], "Input"],

Cell[BoxData[{
    \(\(Clear[dx];\)\), "\[IndentingNewLine]", 
    \(\(Clear[dy];\)\)}], "Input"],

Cell[BoxData[
    \(\(\( (*\ Set\ the\ simplification\ equation, \ 
      since\ we\ choose\ the\ local\ normal\ direction\ as\ the\ z - 
        axis\ of\ our\ 2  
          PP\ parametrization\ *) \)\(\ \)\(\[IndentingNewLine]\)\(\(wx = 
        0;\)\[IndentingNewLine]
    \(wy = 0;\)\[IndentingNewLine]
    \(w = 0;\)\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[A]\)], "Input"],

Cell[BoxData[
    \(\(-\(\((\((1 + dx\^2 + dy\^2)\)\ m\^2\ \((\(-2\)\ dy\ m\^2 - 
                2\ dy\^3\ \((\(-1\) + m\^2)\) + 
                dy\^2\ \((\(-1\) + 
                      m\^2)\)\ \@\(dy\^2\ \((m\^2 + dx\^2\ \((\(-1\) + \
m\^2)\) + dy\^2\ \((\(-1\) + m\^2)\))\)\) + \((1 + 
                      m\^2)\)\ \@\(dy\^2\ \((m\^2 + dx\^2\ \((\(-1\) + \
m\^2)\) + dy\^2\ \((\(-1\) + m\^2)\))\)\) + 
                dx\^2\ \((\(-1\) + 
                      m\^2)\)\ \((\(-2\)\ dy + \@\(dy\^2\ \((m\^2 + dx\^2\ \
\((\(-1\) + m\^2)\) + dy\^2\ \((\(-1\) + m\^2)\))\)\))\))\)\ \((wxy\^2 - 
                wxx\ wyy)\))\)/\((\((m\^2 + dx\^2\ \((\(-1\) + m\^2)\) + \
dy\^2\ \((\(-1\) + m\^2)\))\)\^2\ \@\(dy\^2\ \((m\^2 + dx\^2\ \((\(-1\) + \
m\^2)\) + dy\^2\ \((\(-1\) + m\^2)\))\)\))\)\)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(A = \(-\((\((1 + dx\^2 + dy\^2)\)\ m\^2\ \((2\ dy\ m\^2 + 
                    2\ dy\^3\ \((\(-1\) + m\^2)\) + 
                    dy\^2\ \((\(-1\) + 
                          m\^2)\)\ \@\(dy\^2\ \((m\^2 + dx\^2\ \((\(-1\) + \
m\^2)\) + dy\^2\ \((\(-1\) + m\^2)\))\)\) + \((1 + 
                          m\^2)\)\ \@\(dy\^2\ \((m\^2 + dx\^2\ \((\(-1\) + \
m\^2)\) + dy\^2\ \((\(-1\) + m\^2)\))\)\) + 
                    dx\^2\ \((\(-1\) + 
                          m\^2)\)\ \((2\ dy + \@\(dy\^2\ \((m\^2 + dx\^2\ \((\
\(-1\) + m\^2)\) + dy\^2\ \((\(-1\) + m\^2)\))\)\))\))\)\ \((wxy\^2 - 
                    wxx\ wyy)\))\)\)/\((\((m\^2 + dx\^2\ \((\(-1\) + m\^2)\) \
+ dy\^2\ \((\(-1\) + m\^2)\))\)\^2\ \@\(dy\^2\ \((m\^2 + dx\^2\ \((\(-1\) + m\
\^2)\) + dy\^2\ \((\(-1\) + m\^2)\))\)\))\);\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[B]\)], "Input"],

Cell[BoxData[
    \(\(-\(\(dy\^2\ \((dy + \@\(dy\^2\ \((m\^2 + dx\^2\ \((\(-1\) + m\^2)\) + \
dy\^2\ \((\(-1\) + m\^2)\))\)\))\)\ \((2\ dx\ dy\ wxy - 
                dx\^2\ wyy + \((1 + dx\^2)\)\ m\^2\ \((wxx + wyy)\) + 
                dy\^2\ \((\((\(-1\) + m\^2)\)\ wxx + 
                      m\^2\ wyy)\))\)\)\/\((dy\^2\ \((m\^2 + dx\^2\ \((\(-1\) \
+ m\^2)\) + dy\^2\ \((\(-1\) + m\^2)\))\))\)\^\(3/2\)\)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(B = \(-\(\((dy\^2\ \((dy + \@\(dy\^2\ \((m\^2 + dx\^2\ \((\(-1\) + \
m\^2)\) + dy\^2\ \((\(-1\) + m\^2)\))\)\))\)\ \((2\ dx\ dy\ wxy - 
                    dx\^2\ wyy + \((1 + dx\^2)\)\ m\^2\ \((wxx + wyy)\) + 
                    dy\^2\ \((\((\(-1\) + m\^2)\)\ wxx + 
                          m\^2\ wyy)\))\))\)/\((dy\^2\ \((m\^2 + dx\^2\ \
\((\(-1\) + m\^2)\) + dy\^2\ \((\(-1\) + m\^2)\))\))\)\^\(3/2\)\)\);\)\)], \
"Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CForm[dy\^3]\)], "Input"],

Cell["Power(dy,3)", "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CC\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\( (*\ 
      further\ alter\ the\ viewing\ direction\ s . t . \ dx = \(0\ and\ dy = 
          0\)\ *) \)\(\[IndentingNewLine]\)\(\(dx = 0;\)\[IndentingNewLine]
    \(dy = 0;\)\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[B]\)], "Input"],

Cell[BoxData[
    \(\(-\(\(\((\(-1\) + m)\)\ \((wxx + wxy)\)\)\/m\)\)\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowSize->{916, 907},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 276, 5, 50, "Input"],
Cell[2033, 58, 644, 13, 230, "Input"],

Cell[CellGroupData[{
Cell[2702, 75, 328, 6, 50, "Input"],
Cell[3033, 83, 8069, 112, 1036, "Output"]
}, Open  ]],
Cell[11117, 198, 3234, 45, 512, "Input"],
Cell[14354, 245, 874, 12, 136, "Input"],

Cell[CellGroupData[{
Cell[15253, 261, 45, 1, 30, "Input"],
Cell[15301, 264, 976, 14, 128, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16314, 283, 45, 1, 30, "Input"],
Cell[16362, 286, 558, 8, 71, "Output"]
}, Open  ]],
Cell[16935, 297, 204, 5, 110, "Input"],
Cell[17142, 304, 338, 7, 90, "Input"],

Cell[CellGroupData[{
Cell[17505, 315, 34, 1, 30, "Input"],
Cell[17542, 318, 206, 3, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17785, 326, 34, 1, 30, "Input"],
Cell[17822, 329, 206, 3, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18065, 337, 34, 1, 30, "Input"],
Cell[18102, 340, 219, 3, 54, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18358, 348, 34, 1, 30, "Input"],
Cell[18395, 351, 219, 3, 54, "Output"]
}, Open  ]],
Cell[18629, 357, 524, 12, 190, "Input"],
Cell[19156, 371, 384, 7, 110, "Input"],
Cell[19543, 380, 2121, 56, 230, "Input"],
Cell[21667, 438, 97, 2, 50, "Input"],
Cell[21767, 442, 338, 7, 110, "Input"],

Cell[CellGroupData[{
Cell[22130, 453, 44, 1, 30, "Input"],
Cell[22177, 456, 810, 13, 110, "Output"]
}, Open  ]],
Cell[23002, 472, 832, 13, 113, "Input"],

Cell[CellGroupData[{
Cell[23859, 489, 44, 1, 30, "Input"],
Cell[23906, 492, 427, 6, 52, "Output"]
}, Open  ]],
Cell[24348, 501, 450, 7, 83, "Input"],

Cell[CellGroupData[{
Cell[24823, 512, 45, 1, 31, "Input"],
Cell[24871, 515, 29, 0, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24937, 520, 35, 1, 30, "Input"],
Cell[24975, 523, 35, 1, 29, "Output"]
}, Open  ]],
Cell[25025, 527, 216, 4, 70, "Input"],

Cell[CellGroupData[{
Cell[25266, 535, 44, 1, 30, "Input"],
Cell[25313, 538, 83, 1, 42, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

